@@ -1,10 +1,21 @@
+import importlib
 import io
+import logging
 from collections import OrderedDict
 from typing import Any, Tuple
 
-import dill
+import pickle5 as pickle
 import torch
 
+logger = logging.getLogger(__name__)
+console = logging.StreamHandler()
+logger.addHandler(console)
+logger.setLevel(logging.INFO)
+
+
+def hf_hub_is_available():
+    return importlib.util.find_spec("huggingface_hub") is not None
+
 
 class ModelOutput(OrderedDict):
     """Base ModelOutput class fixing the output type from the models. This class is inspired from
@@ -32,7 +43,7 @@ class ModelOutput(OrderedDict):
         return tuple(self[k] for k in self.keys())
 
 
-class CPU_Unpickler(dill.Unpickler):
+class CPU_Unpickler(pickle.Unpickler):
     def find_class(self, module, name):
         if module == "torch.storage" and name == "_load_from_bytes":
             return lambda b: torch.load(io.BytesIO(b), map_location="cpu")
